--- /home/tromey/gnu/Nightly/classpath/classpath/gnu/java/lang/CharData.java 2002-03-09 14:20:04.000000000 -0700
+++ gnu/java/lang/CharData.java 2004-07-10 02:19:09.000000000 -0600
@@ -41,9 +41,9 @@
/**
* This contains the info about the unicode characters, that
* java.lang.Character needs. It is generated automatically from
* doc/unicode/UnicodeData-3.0.0.txt and
* doc/unicode/SpecialCasing-2.txt, by some
* perl scripts. These Unicode definition file can be found on the
* http://www.unicode.org website.
* JDK 1.4 uses Unicode version 3.0.0.
*
@@ -73,7 +73,7 @@
/**
* The Unicode definition file that was parsed to build this database.
*/
- String SOURCE = "doc/unicode/UnicodeData-3.0.0.txt";
+ String SOURCE = "gnu/gcj/convert/UnicodeData-3.0.0.txt";
/**
* The character shift amount to look up the block offset. In other words,
@@ -41,9 +41,9 @@
* This contains the info about the unicode characters, that
* java.lang.Character needs. It is generated automatically from
- * doc/unicode/UnicodeData-3.0.0.txt and
- * doc/unicode/SpecialCasing-2.txt, by some
- * perl scripts. These Unicode definition file can be found on the
+ * gnu/gcj/convert/UnicodeData-3.0.0.txt and
+ * gnu/gcj/convert/SpecialCasing-2.txt, by some
+ * perl scripts. These Unicode definition files can be found on the
* http://www.unicode.org website.
* JDK 1.4 uses Unicode version 3.0.0.